<template>
  <div class="left3">
    <div class="title">
      <span>人口分析</span>
      <img class="img" src="../../../assets/img/zonlan (9).png" alt="" />
    </div>
    <div id="content"></div>
  </div>
</template>

<script>
import * as echarts from "echarts";
export default {
  name: "left3",
  mounted() {
    this.echarts3();
  },
  methods: {
    echarts3() {
      var chartDom = document.getElementById("content");
      var myChart = echarts.init(chartDom);
      var option;

      option = {
        title: {
          text: "人口发展情况",
          top: "-50px",
          textStyle: {
            color: "#fff",
            fontSize: 36,
          },
        },
        tooltip: {
          trigger: "axis",
          textStyle: {
            color: "#fff",
            fontSize: 36,
          },
        },
        legend: {
          itemWidth: 15,
          itemHeight: 10,
          left: "center",
          textStyle: {
            fontSize: 32,
            color: "#fff",
          },
          data: ["出生率", "死亡率", "自然增长率"],
        },
        grid: {
          left: "3%",
          right: "4%",
          bottom: "21%",
          height: "75%",
          containLabel: true,
        },
        toolbox: {
          feature: {
            // dataView: { show: true, readOnly: false },
            magicType: { show: true, type: ["bar"] },
            restore: { show: true },
            saveAsImage: { show: true },
          },
        },

        xAxis: {
          type: "category",
          boundaryGap: false,
          data: [
            "2009",
            "2010",
            "2011",
            "2012",
            "2013",
            "2014",
            "2015",
            "2016",
            "2017",
            "2018",
            "2019",
            "2020",
          ],
          axisLabel: {
            margin: 5,
            textStyle: {
              fontSize: 24,
              color: "#B5B5B5", //设置x轴标签文字颜色
            },
          },
          axisLine: {
            show: true,
            lineStyle: {
              color: "#B5B5B5", //设置轴线颜色
            },
          },
        },
        yAxis: [
          {
            type: "value",
            splitLine: { show: false }, //去除网格线
            splitNumber: "6",
            axisLabel: {
              margin: 0, //设置y轴标签名称与轴线间距
              textStyle: {
                fontSize: 32,
                color: "#B5B5B5", //设置y轴标签文字颜色
              },
            },
            axisLine: {
              //设置y轴轴线样式
              show: true,
              lineStyle: {
                color: "#56626E", //设置轴线颜色
              },
            },
            max: 80,
            min: -80,
          },
        ],

        series: [
          {
            name: "出生率",
            type: "line",
            stack: "总量",
            data: [20, 12, 35, 22, 8, 10, 22, 5, 36, 15, 34, 10],
            itemStyle: {
              normal: {
                color: "#D4BE10", //改变折线点的颜色
                lineStyle: {
                  color: "#D4BE10", //改变折线颜色
                },
              },
            },
          },
          {
            name: "死亡率",
            type: "line",
            stack: "总量",
            data: [10, 25, 5, 12, 30, 32, 10, 5, 25, 6, 31, 39],
            itemStyle: {
              normal: {
                color: "#01EE6A", //改变折线点的颜色
                lineStyle: {
                  color: "#01EE6A", //改变折线颜色
                },
              },
            },
          },
          {
            name: "自然增长率",
            type: "line",
            stack: "总量",
            data: [-20, -22, -2, -14, -20, -3, -20, -12, -15, -30, -10, -32],
            itemStyle: {
              normal: {
                color: "#00EAFF", //改变折线点的颜色
                lineStyle: {
                  color: "#00EAFF", //改变折线颜色
                },
              },
            },
          },
        ],
      };

      option && myChart.setOption(option);
    },
  },
};
</script>

<style lang="less" scoped>
.left3 {
  box-sizing: border-box;
  overflow: hidden;
  width: 100%;
  height: 32%;

  .title {
    width: 100%;
    position: relative;
    img {
      width: 100%;
    }
    span {
      font-size: 75px;
      font-weight: 400;
      color: #ffe86b;
      background: linear-gradient(0deg, #bce7ff 0%, #69efff 98.6572265625%);
      -webkit-background-clip: text;
      -webkit-text-fill-color: transparent;
      position: absolute;
      left: 50%;
      top: 0;
      transform: translateX(-50%);
    }
  }
  #content {
    width: 100%;
    height: 100%;
    top: 8%;
  }
}
</style>
